searchData={"items":[{"type":"module","title":"TPM","doc":"Elixir wrapper for [tpm2-tools](https://github.com/tpm2-software/tpm2-tools).","ref":"TPM.html"},{"type":"function","title":"TPM.clear/1","doc":"Clear the TPM.","ref":"TPM.html#clear/1"},{"type":"function","title":"Opts - TPM.clear/1","doc":"- `confirm` - Must be set `true` to clear the TPM. This prevents accidental               auto-completion in IEx.","ref":"TPM.html#clear/1-opts"},{"type":"function","title":"TPM.getcap/1","doc":"Get TPM capabilities.","ref":"TPM.html#getcap/1"},{"type":"function","title":"TPM.nvdefine/1","doc":"Define a TPM Non-Volatile (NV) index.","ref":"TPM.html#nvdefine/1"},{"type":"function","title":"Opts - TPM.nvdefine/1","doc":"- `address` - NV index or offset number.\n- `size`    - Specifies  the  size  of data area in bytes. Defaults to               MAX_NV_INDEX_SIZE which is typically 2048.","ref":"TPM.html#nvdefine/1-opts"},{"type":"function","title":"TPM.nvread/2","doc":"Read the data stored in a Non-Volatile (NV) index.","ref":"TPM.html#nvread/2"},{"type":"function","title":"Args - TPM.nvread/2","doc":"- `address` - NV memory address.","ref":"TPM.html#nvread/2-args"},{"type":"function","title":"Opts - TPM.nvread/2","doc":"- `output` - File path to write the NV memory's contents to. Returns `:ok`.","ref":"TPM.html#nvread/2-opts"},{"type":"function","title":"TPM.nvwrite/2","doc":"Write data to a Non-Volatile (NV) index.","ref":"TPM.html#nvwrite/2"},{"type":"function","title":"Args - TPM.nvwrite/2","doc":"- `address` - NV memory address.\n- `path`    - File path to read into the NV memory's contents.","ref":"TPM.html#nvwrite/2-args"},{"type":"type","title":"TPM.tpm2_error/0","doc":"","ref":"TPM.html#t:tpm2_error/0"},{"type":"module","title":"TPM.Crypto","doc":"Interface with OTP crypto and X509.","ref":"TPM.Crypto.html"},{"type":"function","title":"TPM.Crypto.csr/3","doc":"Create a certificate signing request for a device.","ref":"TPM.Crypto.html#csr/3"},{"type":"function","title":"Args - TPM.Crypto.csr/3","doc":"- `privkey`       - OTP `engine_key_ref` private key reference.\n- `organization`  - Organization (company) name to list in the certificate.\n- `serial_number` - Device serial number or unique identifier.","ref":"TPM.Crypto.html#csr/3-args"},{"type":"function","title":"TPM.Crypto.engine/0","doc":"Returns an OTP crypto engine for tpm2tss.","ref":"TPM.Crypto.html#engine/0"},{"type":"function","title":"TPM.Crypto.privkey/1","doc":"Returns an OTP crypto [engine_key_ref](https://www.erlang.org/docs/22/man/crypto#type-engine_key_ref)\n(privkey).","ref":"TPM.Crypto.html#privkey/1"},{"type":"function","title":"Args - TPM.Crypto.privkey/1","doc":"- `path` - File path of the TPM private key in PEM format.","ref":"TPM.Crypto.html#privkey/1-args"},{"type":"function","title":"TPM.Crypto.pubkey/1","doc":"Returns an OTP [rsa_public](https://www.erlang.org/docs/22/man/crypto#type-rsa_public)\npublic key based on an OTP [engine_key_ref](https://www.erlang.org/docs/22/man/crypto#type-engine_key_ref)\nprivate key.","ref":"TPM.Crypto.html#pubkey/1"},{"type":"function","title":"Args - TPM.Crypto.pubkey/1","doc":"- `privkey` - OTP `engine_key_ref` private key reference.","ref":"TPM.Crypto.html#pubkey/1-args"},{"type":"type","title":"TPM.Crypto.engine_key_ref/0","doc":"[:crypto.engine_key_ref](https://www.erlang.org/docs/22/man/crypto#type-engine_key_ref)","ref":"TPM.Crypto.html#t:engine_key_ref/0"},{"type":"type","title":"TPM.Crypto.rsa_public_key/0","doc":"[:crypto.rsa_public_key](https://www.erlang.org/docs/22/man/crypto#type-rsa_public)","ref":"TPM.Crypto.html#t:rsa_public_key/0"},{"type":"type","title":"TPM.Crypto.x509_csr/0","doc":"[X509.CSR.t](https://hexdocs.pm/x509/X509.CSR.html#t:t/0)","ref":"TPM.Crypto.html#t:x509_csr/0"},{"type":"module","title":"TPM.TSS","doc":"Elixir wrapper for [tpm2tss](https://github.com/tpm2-software/tpm2-tss).","ref":"TPM.TSS.html"},{"type":"function","title":"TPM.TSS.genkey/1","doc":"Generate TPM keys for tpm2-tss-engine.","ref":"TPM.TSS.html#genkey/1"},{"type":"function","title":"Args - TPM.TSS.genkey/1","doc":"- `output_path` - File path to save the generated key.","ref":"TPM.TSS.html#genkey/1-args"},{"type":"extras","title":"TPM","doc":"# TPM\n\nUse a Trusted Platform Module (TPM) with Elixir and [Nerves](https://nerves-project.org/).\n\nA TPM can be used to secure the cryptographic keys used for things like SSL/TLS\nconnections and disk encryption.\n\nThis library is mainly a wrapper around existing TPM libraries, which are\nlinked in the module docs of this repo. Documentation on how a TPM works can\nbe found there.","ref":"readme.html"},{"type":"extras","title":"Installation - TPM","doc":"This package can be installed by adding `tpm` to your list of dependencies\nin `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tpm, \"~> 0.1.0\"}\n  ]\nend\n```\n\nAdd the following to `nerves_defconfig`:\n\n```kconfig\nBR2_PACKAGE_TPM2_TOOLS=y\nBR2_PACKAGE_TPM2_TOOLS_FAPI=y\nBR2_PACKAGE_TPM2_TSS_ENGINE=y\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - TPM","doc":"Generate a private key. Unlike a traditional private key file, this one requires\nthe TPM to function.\n\n```ex\n:ok = TPM.TSS.genkey(\"/data/.ssh/key\")\n```\n\nA copy of the key can be stored in the TPM's non-volatile memory as a backup.\nFor example, if the device were factory reset and the disk wiped, the key could\nbe retrieved from the TPM's NV memory and its prior identity would be retained.\n\n```ex\n{:ok, address} = TPM.nvdefine(size: 1024)\n:ok = TPM.nvwrite(address, \"/data/.ssh/key\")\n```\n\nThe private key can be used within the BEAM VM by getting an [engine_key_ref](https://www.erlang.org/docs/22/man/crypto#type-engine_key_ref).\n\n```ex\n{:ok, privkey} = TPM.Crypto.privkey(\"/data/.ssh/key\")\n```","ref":"readme.html#usage"},{"type":"extras","title":"Creating a certificate signing request - TPM","doc":"Some connections require the client to provide a signed certificate, or else\nthe connection will be rejected.\n\nGenerate a public key from the private key reference.\n\n```ex\npublic_key_pem =\n  privkey\n  |> TPM.Crypto.pubkey\n  |> X509.PublicKey.to_pem\n\nFile.write!(\"/data/.ssh/key.pub\", public_key_pem)\n```\n\nCreate the certificate signing request.\n\n```ex\ncsr_pem =\n  privkey\n  |> TPM.Crypto.csr(\"Device ID\", \"My Organization\")\n  |> X509.CSR.to_pem\n\nFile.write!(\"/data/.ssh/csr.pem\", csr_pem)\n```\n\nCopy the CSR from the device with `cat` on the device or `scp` on the host and\nsign the CSR with the root or intermediate CA. Copy the signed certificate back\nto the device. For some connections, concatenating the entire certificate bundle\ninto a file may be necessary.","ref":"readme.html#creating-a-certificate-signing-request"},{"type":"extras","title":"Setting the TCTI - TPM","doc":"By default, the TPM Command Transmission Interface (TCTI) is set to\n`device:/dev/tpmrm0` since this is the default path for a hardware TPM.\nThis can be changed by setting the `:tcti` application property in the\nproject's mix config.\n\n```ex\nconfig :tpm, :tcti, \"device:/dev/tpmrm0\"\n```","ref":"readme.html#setting-the-tcti"},{"type":"extras","title":"LICENSE","doc":"The MIT License (MIT)\n\nCopyright 2024 Redwire Labs LLC\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in\nall copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\nTHE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}